## **:- Change Log -:**

> **0.0.1** -- [ 16 JULY 2023 ]  
> [ NOTICE ]  
> [ ! ] - Initial Release

> **0.0.2** -- [ 16 JULY 2023 ]  
> [ FIXED ]  
> [+] - Import and Run

> **0.0.3** -- [ 17 JULY 2023 ]  
> [ ADDED ]  
> [+] Package download statistics  
> [+] More Package info

> **0.0.4** -- [ 18 JULY 2023 ]  
> [ FIXED ]  
> [+] - windows support
